==> sentry-23.3.0-0-py38-none-any.whl: sentry/replays/validators.py <==
from rest_framework import serializers

VALID_FIELD_SET = {
    "id",
    "title",
    "project_id",
    "errorIds",
    "traceIds",
    "urls",
    "startedAt",
    "finishedAt",
    "duration",
    "countErrors",
    "countSegments",
    "countUrls",
    "longestTransaction",
    "platform",
    "environment",
    "release",
    "dist",
    "user",
    "os",
    "browser",
    "device",
    "sdk",
    "tags",
    "activity",
}


class ReplayValidator(serializers.Serializer):
    statsPeriod = serializers.CharField(
        help_text=(
            "This defines the range of the time series, relative to now. "
            "The range is given in a `<number><unit>` format. "
            "For example `1d` for a one day range. Possible units are `m` for minutes, `h` for hours, `d` for days and `w` for weeks."
            "You must either provide a `statsPeriod`, or a `start` and `end`."
        ),
        required=False,
    )
    start = serializers.DateTimeField(
        help_text="This defines the start of the time series range as an explicit datetime, either in UTC ISO8601 or epoch seconds."
        "Use along with `end` instead of `statsPeriod`.",
        required=False,
    )
    end = serializers.DateTimeField(
        help_text=(
            "This defines the inclusive end of the time series range as an explicit datetime, either in UTC ISO8601 or epoch seconds."
            "Use along with `start` instead of `statsPeriod`."
        ),
        required=False,
    )
    field = serializers.ChoiceField(
        VALID_FIELD_SET,
        help_text="Specifies a field that should be marshaled in the output. Invalid fields will be rejected.",
        required=False,
    )
    project = serializers.ListField(
        required=False, help_text="The ID of the projects to filter by."
    )
    environment = serializers.CharField(help_text="The environment to filter by.", required=False)
    sort = serializers.CharField(help_text="The field to sort the output by.", required=False)
    query = serializers.CharField(
        help_text="A structured query string to filter the output by.", required=False
    )

==> sentry-23.4.0-0-py38-none-any.whl: sentry/replays/validators.py <==
from rest_framework import serializers

VALID_FIELD_SET = {
    "activity",
    "browser",
    "count_errors",
    "count_segments",
    "count_urls",
    "device",
    "dist",
    "duration",
    "environment",
    "error_ids",
    "finished_at",
    "id",
    "is_archived",
    "os",
    "platform",
    "project_id",
    "releases",
    "sdk",
    "started_at",
    "tags",
    "trace_ids",
    "urls",
    "user",
}


class ReplayValidator(serializers.Serializer):
    statsPeriod = serializers.CharField(
        help_text=(
            "This defines the range of the time series, relative to now. "
            "The range is given in a `<number><unit>` format. "
            "For example `1d` for a one day range. Possible units are `m` for minutes, `h` for hours, `d` for days and `w` for weeks."
            "You must either provide a `statsPeriod`, or a `start` and `end`."
        ),
        required=False,
    )
    start = serializers.DateTimeField(
        help_text="This defines the start of the time series range as an explicit datetime, either in UTC ISO8601 or epoch seconds."
        "Use along with `end` instead of `statsPeriod`.",
        required=False,
    )
    end = serializers.DateTimeField(
        help_text=(
            "This defines the inclusive end of the time series range as an explicit datetime, either in UTC ISO8601 or epoch seconds."
            "Use along with `start` instead of `statsPeriod`."
        ),
        required=False,
    )
    field = serializers.MultipleChoiceField(
        VALID_FIELD_SET,
        help_text="Specifies a field that should be marshaled in the output. Invalid fields will be rejected.",
        required=False,
    )
    project = serializers.ListField(
        required=False, help_text="The ID of the projects to filter by."
    )
    environment = serializers.CharField(help_text="The environment to filter by.", required=False)
    sort = serializers.CharField(help_text="The field to sort the output by.", required=False)
    query = serializers.CharField(
        help_text="A structured query string to filter the output by.", required=False
    )
